@@ -32,7 +32,7 @@ Example:
 default_app_config = "django_cfg.apps.DjangoCfgConfig"
 
 # Version information
-__version__ = "1.5.32"
+__version__ = "1.5.49"
 __license__ = "MIT"
 
 # Setup warnings debug early (checks env var only at this point)
@@ -40,6 +40,14 @@ __license__ = "MIT"
 from .core.debug import setup_warnings_debug
 setup_warnings_debug()
 
+# Start Django startup timer early (at module import time)
+try:
+    from .core.integration.timing import start_django_timer, get_django_timer
+    if not get_django_timer():
+        start_django_timer()
+except ImportError:
+    pass
+
 # Import registry for organized lazy loading
 from .config import LIB_NAME
 from .registry import DJANGO_CFG_REGISTRY
