@@ -49,78 +49,15 @@ class TestingViewSet(AdminAPIMixin, viewsets.ViewSet):
 
     # Scenario definitions
     SCENARIOS = {
-        'success': {
-            'id': 'success',
-            'name': 'Success Task',
-            'description': 'Simple task that always succeeds after specified duration',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_success_task',
+        'heartbeat': {
+            'id': 'heartbeat',
+            'name': 'Scheduler Heartbeat',
+            'description': 'Simple heartbeat task for testing RQ scheduler (development mode only)',
+            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_scheduler_heartbeat',
             'default_args': [],
-            'default_kwargs': {'duration': 2, 'message': 'Demo task completed'},
-            'estimated_duration': 2,
-        },
-        'failure': {
-            'id': 'failure',
-            'name': 'Failure Task',
-            'description': 'Task that always fails with ValueError exception',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_failure_task',
-            'default_args': [],
-            'default_kwargs': {'error_message': 'Simulated failure'},
+            'default_kwargs': {},
             'estimated_duration': 1,
         },
-        'slow': {
-            'id': 'slow',
-            'name': 'Slow Task',
-            'description': 'Long-running task for testing timeouts and monitoring',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_slow_task',
-            'default_args': [],
-            'default_kwargs': {'duration': 30, 'step_interval': 5},
-            'estimated_duration': 30,
-        },
-        'progress': {
-            'id': 'progress',
-            'name': 'Progress Task',
-            'description': 'Task that updates progress in job.meta for progress bar testing',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_progress_task',
-            'default_args': [],
-            'default_kwargs': {'total_items': 100},
-            'estimated_duration': 10,
-        },
-        'retry': {
-            'id': 'retry',
-            'name': 'Retry Task',
-            'description': 'Task that fails N times before succeeding (retry logic testing)',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_retry_task',
-            'default_args': [],
-            'default_kwargs': {'max_attempts': 3, 'fail_until_attempt': 2},
-            'estimated_duration': 3,
-        },
-        'random': {
-            'id': 'random',
-            'name': 'Random Task',
-            'description': 'Task with configurable success/failure probability',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_random_task',
-            'default_args': [],
-            'default_kwargs': {'success_rate': 0.7},
-            'estimated_duration': 2,
-        },
-        'memory': {
-            'id': 'memory',
-            'name': 'Memory Intensive Task',
-            'description': 'Task that allocates specified MB of memory',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_memory_intensive_task',
-            'default_args': [],
-            'default_kwargs': {'mb_to_allocate': 100},
-            'estimated_duration': 5,
-        },
-        'cpu': {
-            'id': 'cpu',
-            'name': 'CPU Intensive Task',
-            'description': 'Task with heavy CPU computation',
-            'task_func': 'django_cfg.apps.integrations.rq.tasks.demo_tasks.demo_cpu_intensive_task',
-            'default_args': [],
-            'default_kwargs': {'iterations': 1000000},
-            'estimated_duration': 10,
-        },
     }
 
     @extend_schema(
