@@ -4,7 +4,7 @@ Generator protocols for type safety.
 Defines interfaces that all settings generators must implement.
 """
 
-from typing import Protocol, Dict, Any, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict, Protocol
 
 if TYPE_CHECKING:
     from ..base.config_model import DjangoConfig
