@@ -1,7 +1,14 @@
 """Core type definitions for django-cfg."""
 
+from .aliases import (
+    AppLabel,
+    DatabaseAlias,
+    EnvironmentString,
+    MiddlewareLabel,
+    UrlPath,
+    UrlPattern,
+)
 from .enums import EnvironmentMode, StartupInfoMode
-from .aliases import EnvironmentString, DatabaseAlias, AppLabel, MiddlewareLabel, UrlPath, UrlPattern
 
 __all__ = [
     "EnvironmentMode",
