@@ -78,7 +78,7 @@ class ConfigurationValidator:
             errors.append("SECRET_KEY must be at least 50 characters long")
         else:
             # Check for insecure patterns in production
-            if config.env_mode == 'production':
+            if config.is_production:
                 insecure_patterns = [
                     'django-insecure',
                     'change-me',
@@ -107,7 +107,7 @@ class ConfigurationValidator:
                     errors.append(f"Invalid hostname in ALLOWED_HOSTS[{i}]: '{host}'")
 
             # Production-specific validation
-            if config.env_mode == 'production' and '*' in allowed_hosts:
+            if config.is_production and '*' in allowed_hosts:
                 errors.append("Wildcard '*' in ALLOWED_HOSTS is not recommended for production")
 
         return errors
@@ -140,7 +140,7 @@ class ConfigurationValidator:
         errors = []
 
         # Environment-specific security validation
-        if config.env_mode == 'production':
+        if config.is_production:
             # Allow DEBUG=True in production for development purposes
             pass
 
@@ -158,9 +158,7 @@ class ConfigurationValidator:
         """Validate environment-specific consistency."""
         errors = []
 
-        environment = config.env_mode
-
-        if environment == 'production':
+        if config.is_production:
             # Production requirements - allow DEBUG=True for development
             pass
 
