@@ -111,13 +111,23 @@ class PydanticAdminMixin:
         # Fieldsets
         if config.fieldsets:
             cls.fieldsets = config.to_django_fieldsets()
-
         # Also convert fieldsets if they're defined directly in the class as FieldsetConfig objects
         elif hasattr(cls, 'fieldsets') and isinstance(cls.fieldsets, list):
             from ..config import FieldsetConfig
             if cls.fieldsets and isinstance(cls.fieldsets[0], FieldsetConfig):
                 cls.fieldsets = tuple(fs.to_django_fieldset() for fs in cls.fieldsets)
 
+        # Collect widget configurations from AdminConfig.widgets for custom JSON widget configs
+        cls._field_widget_configs = {}
+        if config.widgets:
+            for widget_config in config.widgets:
+                if hasattr(widget_config, 'field') and hasattr(widget_config, 'to_widget_kwargs'):
+                    field_name = widget_config.field
+                    cls._field_widget_configs[field_name] = widget_config.to_widget_kwargs()
+                    logger.debug(f"Registered widget config for field '{field_name}' from AdminConfig.widgets")
+                else:
+                    logger.warning(f"Invalid widget config in AdminConfig.widgets: {widget_config}")
+
         # Actions
         if config.actions:
             cls._register_actions(config)
@@ -382,8 +392,15 @@ class PydanticAdminMixin:
 
     @classmethod
     def _register_actions(cls, config: AdminConfig):
-        """Register actions from ActionConfig with Unfold decorator support."""
-        action_functions = []
+        """
+        Register actions from ActionConfig with Unfold decorator support.
+
+        Supports two types of actions:
+        - bulk: Traditional bulk actions (require selected items)
+        - changelist: Buttons above the listing (no selection required)
+        """
+        bulk_action_functions = []
+        changelist_action_functions = []
 
         for action_config in config.actions:
             # Get handler function
@@ -394,15 +411,19 @@ class PydanticAdminMixin:
                 'description': action_config.description,
             }
 
-            # Add variant if specified
+            # Add URL path for changelist actions
+            if action_config.action_type == 'changelist':
+                url_path = action_config.url_path or action_config.name.replace('_', '-')
+                decorator_kwargs['url_path'] = url_path
+
+            # Add variant (Unfold uses ActionVariant enum, but we accept strings)
             if action_config.variant and action_config.variant != 'default':
                 decorator_kwargs['attrs'] = decorator_kwargs.get('attrs', {})
                 decorator_kwargs['attrs']['class'] = f'button-{action_config.variant}'
 
             # Add icon if specified
             if action_config.icon:
-                decorator_kwargs['attrs'] = decorator_kwargs.get('attrs', {})
-                decorator_kwargs['attrs']['data-icon'] = action_config.icon
+                decorator_kwargs['icon'] = action_config.icon
 
             # Add confirmation if enabled
             if action_config.confirmation:
@@ -419,13 +440,26 @@ class PydanticAdminMixin:
             # Store for later registration
             action_name = action_config.name
             setattr(cls, action_name, decorated_handler)
-            action_functions.append(action_name)
 
-        # Set actions list
-        if hasattr(cls, 'actions') and cls.actions:
-            cls.actions = list(cls.actions) + action_functions
-        else:
-            cls.actions = action_functions
+            # Add to appropriate list
+            if action_config.action_type == 'changelist':
+                changelist_action_functions.append(action_name)
+            else:  # bulk
+                bulk_action_functions.append(action_name)
+
+        # Set bulk actions list
+        if bulk_action_functions:
+            if hasattr(cls, 'actions') and cls.actions:
+                cls.actions = list(cls.actions) + bulk_action_functions
+            else:
+                cls.actions = bulk_action_functions
+
+        # Set changelist actions list (Unfold's actions_list)
+        if changelist_action_functions:
+            if hasattr(cls, 'actions_list') and cls.actions_list:
+                cls.actions_list = list(cls.actions_list) + changelist_action_functions
+            else:
+                cls.actions_list = changelist_action_functions
 
     def get_queryset(self, request):
         """Apply select_related, prefetch_related, and annotations from config."""
@@ -557,12 +591,53 @@ class PydanticAdminMixin:
         """
         Override form field for specific database field types.
 
-        Automatically detects and customizes encrypted fields from django-crypto-fields.
+        Automatically detects and customizes:
+        - JSON fields (applies django-json-widget for editable fields only)
+        - Encrypted fields from django-crypto-fields
+
         Respects the show_encrypted_fields_as_plain_text setting from AdminConfig.
         Uses custom widgets with copy-to-clipboard functionality.
         """
-        # Check if this is an EncryptedTextField or EncryptedCharField
         field_class_name = db_field.__class__.__name__
+
+        # Auto-apply JSONEditorWidget for editable JSON fields (not readonly)
+        if field_class_name == 'JSONField':
+            # Check if field is editable (not in readonly_fields)
+            is_readonly = db_field.name in self.readonly_fields
+
+            # Only apply for editable fields
+            if not is_readonly:
+                try:
+                    # Use our custom JSONEditorWidget with Unfold theme support
+                    from ..widgets import JSONEditorWidget
+
+                    # Get field-specific config from AdminConfig.widgets
+                    field_widget_config = getattr(self.__class__, '_field_widget_configs', {}).get(db_field.name, {})
+
+                    # Default widget settings with Unfold theme support
+                    widget_kwargs = {
+                        'mode': 'code',
+                        'height': '400px',
+                        'options': {
+                            'modes': ['code', 'tree', 'view'],
+                            # Unfold dark theme colors
+                            'mainMenuBar': True,
+                            'navigationBar': False,
+                        }
+                    }
+
+                    # Override with field-specific config
+                    if field_widget_config:
+                        widget_kwargs.update(field_widget_config)
+                        logger.debug(f"Applied custom JSONWidget config for '{db_field.name}': {field_widget_config}")
+
+                    # Apply JSONEditorWidget (overrides Unfold's UnfoldAdminTextareaWidget)
+                    kwargs['widget'] = JSONEditorWidget(**widget_kwargs)
+                    logger.debug(f"Auto-applied JSONEditorWidget to editable field '{db_field.name}'")
+                except ImportError:
+                    logger.warning("django-json-widget not available, using default textarea")
+
+        # Check if this is an EncryptedTextField or EncryptedCharField
         if 'Encrypted' in field_class_name and ('TextField' in field_class_name or 'CharField' in field_class_name):
             from django import forms
             from ..widgets import EncryptedFieldWidget, EncryptedPasswordWidget
