@@ -1,5 +1,31 @@
 """
-Main admin configuration for declarative admin.
+Declarative Django Admin configuration.
+
+Type-safe, Pydantic-based admin configuration for Django models.
+
+Quick example:
+    admin_config = AdminConfig(
+        model=Product,
+        list_display=['name', 'price', 'stock'],
+        search_fields=['name'],
+        list_filter=['category'],
+    )
+
+Configuration models:
+    - AdminConfig: Main admin configuration (this class)
+    - FieldConfig: Field widgets and display options
+    - FieldsetConfig: Form organization
+    - ActionConfig: Custom admin actions
+    - BackgroundTaskConfig: Background task integration
+    - ResourceConfig: Related resources (docs, links)
+
+Documentation:
+    See ./docs_public/ for full documentation:
+    - overview.md - Module overview and features
+    - quick-start.md - Getting started guide
+    - configuration.md - Complete configuration reference
+    - field-types.md - Available field widgets
+    - examples.md - Real-world examples
 """
 
 from typing import Any, Dict, List, Optional, Tuple, Type, Union
@@ -155,6 +181,13 @@ class AdminConfig(BaseModel):
                     "WARNING: This exposes sensitive data in the admin interface. Use only in trusted environments."
     )
 
+    # Widget configurations
+    widgets: List = Field(
+        default_factory=list,
+        description="Declarative widget configurations for fields. "
+                    "Example: [JSONWidgetConfig(field='config_schema', mode='view', height='500px')]"
+    )
+
     def get_display_field_config(self, field_name: str) -> Optional[FieldConfig]:
         """Get FieldConfig for a specific field."""
         for field_config in self.display_fields:
