@@ -4,7 +4,7 @@ Material Icons for Django CFG Unfold.
 Provides IDE-friendly Material Design Icons constants.
 """
 
-from .constants import Icons, IconCategories
+from .constants import IconCategories, Icons
 
 __all__ = [
     'Icons',
