@@ -1,11 +1,13 @@
 """Validation rules for OpenAPI schema quality."""
 
 from .base import Issue, Severity, ValidationRule
+from .dict_field import DictFieldRule
 from .type_hints import TypeHintRule
 
 __all__ = [
     'Issue',
     'Severity',
     'ValidationRule',
+    'DictFieldRule',
     'TypeHintRule',
 ]
